==> lamindb_schema-0.2.1.tar.gz: lamindb_schema-0.2.1/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🚚 Move models out to `lndb-schema-core` and `lndb-schema-biology` | [9](https://github.com/laminlabs/lamindb-schema/pull/9) | [falexwolf](https://github.com/falexwolf) | 2022-07-23 | 0.2.1
🐛 Fix duplicate foreign key constraint | [8](https://github.com/laminlabs/lamindb-schema/pull/8) | [falexwolf](https://github.com/falexwolf) | 2022-07-22 |
🏗️ Create public schema modules | [7](https://github.com/laminlabs/lamindb-schema/pull/7) | [falexwolf](https://github.com/falexwolf) | 2022-07-22 | 0.2.0
🔥 Remove SQL Model Relationships | [6](https://github.com/laminlabs/lamindb-schema/pull/6) | [falexwolf](https://github.com/falexwolf) | 2022-07-22 |
♻️ Modularize filenames into biology vs. provenance | [5](https://github.com/laminlabs/lamindb-schema/pull/5) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-22 |
✨ Draft schema design 1 for `biometa` | [2](https://github.com/laminlabs/lamindb-schema/pull/2) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-22 |
🚚 Rename table `interface` to `jupynb` (`0560ee3d73dc`) | [4](https://github.com/laminlabs/lamindb-schema/pull/4) | [falexwolf](https://github.com/falexwolf) | 2022-07-21 | 0.1.1
🏗️  Add a `schema_version` table | [3](https://github.com/laminlabs/lamindb-schema/pull/3) | [falexwolf](https://github.com/falexwolf) | 2022-07-19 | 0.1.0
🚚 Bring in code from lamindb repo | [1](https://github.com/laminlabs/lamindb-schema/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-17 | 0.0.2

==> lamindb_schema-0.3.0.tar.gz: lamindb_schema-0.3.0/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🚸 Do not import all modules by default, only core | [10](https://github.com/laminlabs/lamindb-schema/pull/10) | [falexwolf](https://github.com/falexwolf) | 2022-07-25 | 0.3.0
🚚 Move models out to `lndb-schema-core` and `lndb-schema-biology` | [9](https://github.com/laminlabs/lamindb-schema/pull/9) | [falexwolf](https://github.com/falexwolf) | 2022-07-23 | 0.2.1
🐛 Fix duplicate foreign key constraint | [8](https://github.com/laminlabs/lamindb-schema/pull/8) | [falexwolf](https://github.com/falexwolf) | 2022-07-22 |
🏗️ Create public schema modules | [7](https://github.com/laminlabs/lamindb-schema/pull/7) | [falexwolf](https://github.com/falexwolf) | 2022-07-22 | 0.2.0
🔥 Remove SQL Model Relationships | [6](https://github.com/laminlabs/lamindb-schema/pull/6) | [falexwolf](https://github.com/falexwolf) | 2022-07-22 |
♻️ Modularize filenames into biology vs. provenance | [5](https://github.com/laminlabs/lamindb-schema/pull/5) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-22 |
✨ Draft schema design 1 for `biometa` | [2](https://github.com/laminlabs/lamindb-schema/pull/2) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-22 |
🚚 Rename table `interface` to `jupynb` (`0560ee3d73dc`) | [4](https://github.com/laminlabs/lamindb-schema/pull/4) | [falexwolf](https://github.com/falexwolf) | 2022-07-21 | 0.1.1
🏗️  Add a `schema_version` table | [3](https://github.com/laminlabs/lamindb-schema/pull/3) | [falexwolf](https://github.com/falexwolf) | 2022-07-19 | 0.1.0
🚚 Bring in code from lamindb repo | [1](https://github.com/laminlabs/lamindb-schema/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-17 | 0.0.2
